=======
Credits
=======

Development Lead
----------------

* Thibault Cordier <thibault.a.cordier@capgemini.com>
* Vincent Blot <vincent.blot@capgemini.com>
* Louis Lacombe <louis.lacombe@capgemini.com>
* Valentin Laurent <valentin.laurent@capgemini.com>
* Hussein Jawad <hussein.jawad@capgemini.com>

Emeritus Core Developers
------------------------

* Grégoire Martinon <gregoire.martinon@capgemini.com>
* Vianney Taquet <vianney.taquet@gmail.com>

Contributors
------------

* Nicolas Brunel <nicolas.brunel@capgemini.com>
* Issam Ibnouhsein <iibnouhsein@quantmetry.com>
* François Deheeger <francois.deheeger@michelin.com>
* Rémi Adon <remi.adon@protonmail.com>
* Alizé Papp <alize.papp@outlook.com>
* Abdou Akim Goumbala <aagoumbala@quantmetry.com>
* Adirtha Borgohain <adirthaborgohain@gmail.com>
* Thomas Morzadec <tmorzadec@quantmetry.com>
* Julien Roussel <julien.a.roussel@capgemini.com>
* Arnaud Capitaine <arnaud.gc.capitaine@gmail.com>
* Tarik Tazi <ttazi@quantmetry.com>
* Daniel Herbst <daniel.herbst@tum.de>
* Candice Moyet <candice.moyet@capgemini.com>
* Sofiane Ziane <sziane@quantmetry.com>
* Remi Colliaux <remi.colliaux@capgemini.com>
* Arthur Phan <arthur.phan@capgemini.com>
* Rafael Saraiva <rafael.saraiva.de@gmail.com>
* Mehdi Elion <mehdi.elion@gmail.com>
* Sami Kaddani <sami.kaddani@gmail.com>
* Pierre de Fréminville <pidefrem>
* Ambros Marzetta <ambrosm>
* Carl McBride Ellis <Carl-McBride-Ellis>
* Baptiste Calot <baptiste.calot@capgemini.com>
* Leonardo Garma <leonardo.garma@gmail.com>
* Mohammed Jawhar <mohammedjawhar365@gmail.com>
* Syed Affan <saffand03@gmail.com>
To be continued ...
